HGLOBAL

Struct HGLOBAL 

pub struct HGLOBAL(/* private fields */);
Available on crate feature kernel only.
Handle to a global memory block. Originally just a HANDLE.

The allocated memory block is accessible through the GlobalLock method.

Implementations

Source

impl HGLOBAL

pub const unsafe fn from_ptr(p: *mut c_void) -> Self

Constructs a new handle object by wrapping a pointer.

This method can be used as an escape hatch to interoperate with other libraries.

Safety

Be sure the pointer has the correct type and isn’t owned by anyone else, otherwise you may cause memory access violations.

pub const unsafe fn raw_copy(&self) -> Self

Returns a raw copy of the underlying handle pointer.

Safety

As the name implies, raw_copy returns a raw copy of the handle, so closing one of the copies won’t close the others. This means a handle can be used after it has been closed, what can lead to errors and undefined behavior. Even worse: sometimes Windows reuses handle values, so you can call a method on a completely different handle type, what can be catastrophic.

However, in some cases the Windows API demands a copy of the handle – raw_copy is an escape hatch to fill this gap.

pub const unsafe fn as_mut(&mut self) -> &mut *mut c_void

Returns a mutable reference to the underlying raw pointer.

This method can be used as an escape hatch to interoperate with other libraries.

Safety

This method exposes the raw pointer used by raw Windows calls. It’s an opaque pointer to an internal Windows structure, and no dereferencings should be attempted.

pub const fn ptr(&self) -> *mut c_void

Returns the underlying raw pointer.

This method exposes the raw pointer used by raw Windows calls. It’s an opaque pointer to an internal Windows structure, and no dereferencings should be attempted.

This method can be used as an escape hatch to interoperate with other libraries.

Source

impl HGLOBAL

pub fn GlobalAlloc(flags: GMEM, num_bytes: usize) -> SysResult<GlobalFreeGuard>

GlobalAlloc function.

pub fn GlobalFlags(&self) -> SysResult<GMEM>

GlobalFlags function.

pub fn GlobalLock(&self) -> SysResult<GlobalUnlockGuard<'_>>

GlobalLock function.

Calls GlobalSize to retrieve the size of the memory block.

Examples
use winsafe::{self as w, prelude::*, co};

let hglobal = w::HGLOBAL::GlobalAlloc(
    co::GMEM::FIXED | co::GMEM::ZEROINIT,
    120,
)?;

let mut block = hglobal.GlobalLock()?;

block.as_mut_slice()[0] = 40;

// GlobalUnlock() called automatically

// GlobalFree() called automatically
pub fn GlobalReAlloc(&mut self, num_bytes: usize, flags: GMEM) -> SysResult<()>

GlobalReAlloc function.

Originally this method returns the handle to the reallocated memory object; here the original handle is automatically updated.

pub fn GlobalSize(&self) -> SysResult<usize>

GlobalSize function.